@@ -23,12 +23,12 @@ mod gsw_specvol_coefficients;
 mod ffi;
 
 pub mod conversions;
+pub mod earth;
 mod gsw_internal_funcs;
 pub mod volume;
 
 mod error;
 pub use crate::error::{Error, Result};
 
-pub use crate::volume::{
-    alpha, beta, rho, specvol, specvol_alpha_beta, specvol_anom_standard, specvol_sso_0,
-};
+pub use crate::gsw_internal_funcs::specvol_sso_0;
+pub use crate::volume::{alpha, beta, rho, specvol, specvol_alpha_beta, specvol_anom_standard};
